===
API
===

This part of the documentation covers all the interfaces of Stilpy. That
includes TimeGaps and TimeInterval class.

TimeGaps Objects
----------------

.. automodule:: stilpy.timegaps
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    

TimeInterval Objects
--------------------

.. automodule:: stilpy.timeinterval
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: